@@ -1,9 +1,10 @@
 from __future__ import annotations
 
-import itertools
+from collections.abc import Iterable
 from pathlib import Path
-from typing import TYPE_CHECKING, Iterable
+from typing import TYPE_CHECKING
 
+import asyncstdlib
 import discord
 from red_commons.logging import getLogger
 from redbot.core.i18n import Translator
@@ -159,30 +160,32 @@ class EffectsPickerSource(menus.ListPageSource):
 
 
 class QueueSource(menus.ListPageSource):
-    def __init__(self, guild_id: int, cog: CogT):  # noqa
+    def __init__(self, guild_id: int, cog: CogT, history: bool = False):  # noqa
         self.cog = cog
         self.per_page = 10
         self.guild_id = guild_id
+        self.history = history
 
     @property
     def entries(self) -> Iterable[Track]:
         player = self.cog.lavalink.get_player(self.guild_id)
         if not player:
             return []
-        return player.queue.raw_queue
+        return player.history.raw_queue if self.history else player.queue.raw_queue
 
     def is_paginating(self) -> bool:
         return True
 
     async def get_page(self, page_number: int) -> list[Track]:
         base = page_number * self.per_page
-        return list(itertools.islice(self.entries, base, base + self.per_page))
+        return await asyncstdlib.list(asyncstdlib.islice(self.entries, base, base + self.per_page))
 
     def get_max_pages(self) -> int:
         player = self.cog.lavalink.get_player(self.guild_id)
         if not player:
             return 1
-        pages, left_over = divmod(player.queue.size(), self.per_page)
+        pages, left_over = divmod(player.history.size() if self.history else player.queue.size(), self.per_page)
+
         if left_over:
             pages += 1
         return pages or 1
@@ -205,10 +208,13 @@ class QueueSource(menus.ListPageSource):
                 total_pages=self.get_max_pages(),
                 embed=True,
                 messageable=menu.ctx,
+                history=self.history,
             )
-            if player.current
+            if player.current and (player.history.size() if self.history else True)
             else await self.cog.lavalink.construct_embed(
-                description="There's nothing currently being played.",
+                description="There's nothing in recently played."
+                if self.history
+                else "There's nothing currently being played.",
                 messageable=menu.ctx,
             )
         )
@@ -228,7 +234,9 @@ class QueuePickerSource(QueueSource):
         base = page_number * self.per_page
         self.select_options.clear()
         self.select_mapping.clear()
-        for i, track in enumerate(list(itertools.islice(self.entries, base, base + self.per_page)), start=base):
+        for i, track in enumerate(
+            await asyncstdlib.list(asyncstdlib.islice(self.entries, base, base + self.per_page)), start=base
+        ):
             self.select_options.append(await QueueTrackOption.from_track(track=track, index=i))
             self.select_mapping[track.id] = track
         return []
